==> huhk-1.9.1.tar.gz: huhk-1.9.1/service/app_a/asserts/content/asserts_content_question.py <==
import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_question import SqlsContentQuestion


class AssertsContentQuestion(SqlsContentQuestion):
    @allure.step(title="接口返回结果校验")
    def assert_content_question_answerquestion(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_question_answerquestion(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["answerContent", "questionId", "author"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_question_revoke(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_question_revoke(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["operaType", "questionId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_question_getmanegequestionlist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_question_getmanegequestionlist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["endTime", "startTime", "status", "keyWord", "mobile"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_question_getbyid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_question_getbyid(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["questionId"])
        assert True, "数据比较不一致"

==> huhk-1.9.6.tar.gz: huhk-1.9.6/service/app_a/asserts/content/asserts_content_question.py <==
import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_question import SqlsContentQuestion


class AssertsContentQuestion(SqlsContentQuestion):
    @allure.step(title="接口返回结果校验")
    def assert_content_question_answerquestion(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_question_answerquestion(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["answerContent", "author", "questionId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_question_revoke(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_question_revoke(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["operaType", "questionId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_question_getmanegequestionlist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_question_getmanegequestionlist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["keyWord", "mobile", "endTime", "startTime", "status"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_question_getbyid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_question_getbyid(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["questionId"])
        assert True, "数据比较不一致"
